#include <iostream>
#include <vector>
#include <string>

class HashTable {
public:
    HashTable(int size) : table(size, ""), values(size, 0), size(size) {}

    void insert(const std::string& key, int value) {
        int index = hashFunction(key);
        while (!table[index].empty()) {
            index = (index + 1) % size;  // Linear probing
        }
        table[index] = key;
        values[index] = value;
    }

    bool lookup(const std::string& key, int& value) {
        int index = hashFunction(key);
        while (!table[index].empty()) {
            if (table[index] == key) {
                value = values[index];
                return true;
            }
            index = (index + 1) % size;  // Linear probing
        }
        return false;
    }

    void remove(const std::string& key) {
        int index = hashFunction(key);
        while (!table[index].empty()) {
            if (table[index] == key) {
                table[index] = "";  // Mark as deleted
                return;
            }
            index = (index + 1) % size;  // Linear probing
        }
    }

private:
    int hashFunction(const std::string& key) {
        int hashValue = 0;
        for (char ch : key) {
            hashValue += ch;
        }
        return hashValue % size;
    }

    std::vector<std::string> table;
    std::vector<int> values;
    int size;
};

int main() {
    HashTable ht(10);

    ht.insert("apple", 100);
    ht.insert("banana", 150);
    ht.insert("orange", 200);

    int value;
    if (ht.lookup("banana", value)) {
        std::cout << "Value for 'banana': " << value << std::endl;
    }

    ht.remove("banana");
    if (!ht.lookup("banana", value)) {
        std::cout << "'banana' not found." << std::endl;
    }

    return 0;
}

